==> asc_2.4.0.0.orig.tar.gz: asc-2.4.0.0/source/actions/removeobject.h <==
/*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
     Copyright (C) 1994-2008  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
     along with this program; see the file COPYING. If not, write to the 
     Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
     Boston, MA  02111-1307  USA
*/


#ifndef RemoveObjectH
#define RemoveObjectH


#include "action.h"

#include "../typen.h"

class RemoveObject : public GameAction {
      MapCoordinate pos;
      int objectID;
      
      RemoveObject( GameMap* map ) : GameAction( map ) {};
      template<class Child> friend GameAction* GameActionCreator( GameMap* map);
      
      tmemorystreambuf* objectBuffer;

   public:
      RemoveObject( GameMap* gamemap, const MapCoordinate& position, int objectID );
      
      ASCString getDescription() const;
      
      ~RemoveObject();
      
   protected:
      virtual GameActionID getID() const;
      
      virtual ActionResult runAction( const Context& context );
      virtual ActionResult undoAction( const Context& context );
      virtual ActionResult verify();
      
      virtual void readData ( tnstream& stream );
      virtual void writeData ( tnstream& stream ) const;
      
};

#endif

==> asc_2.5.0.0.orig.tar.gz: asc-2.5.0.0/source/actions/removeobject.h <==
/*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
     Copyright (C) 1994-2010  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
     along with this program; see the file COPYING. If not, write to the 
     Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
     Boston, MA  02111-1307  USA
*/


#ifndef RemoveObjectH
#define RemoveObjectH


#include "action.h"

#include "../typen.h"

class RemoveObject : public GameAction {
      MapCoordinate pos;
      int objectID;
      
      // the number of objects that where additionally removed, because they depended on the original one
      int additionalObjectCount;
      
      RemoveObject( GameMap* map ) : GameAction( map ) {};
      template<class Child> friend GameAction* GameActionCreator( GameMap* map);
      
      MemoryStreamStorage* objectBuffer;

   public:
      RemoveObject( GameMap* gamemap, const MapCoordinate& position, int objectID );
      
      ASCString getDescription() const;
      
      ~RemoveObject();
      
   protected:
      virtual GameActionID getID() const;
      
      virtual ActionResult runAction( const Context& context );
      virtual ActionResult undoAction( const Context& context );
      virtual ActionResult verify();
      
      virtual void readData ( tnstream& stream );
      virtual void writeData ( tnstream& stream ) const;
      
};

#endif
